@@ -1,14 +1,15 @@
-# Copyright (C) 2020 by Vd.
+# Copyright (C) 2020-2022 by Vd.
 # This file is part of BetterLogging, my logging improvement.
 # BetterLogging is released under the MIT License (see LICENSE).
 
 
 import logging
+import sys
 from logging import Formatter
 from logging import LogRecord
-from .outer.better_exceptions import ExceptionFormatter
 
 from .colors import colors
+from .outer.better_exceptions import ExceptionFormatter
 from .trace import TRACE
 
 DEFAULT_FORMAT = '%(c_fg_green)s%(asctime)s %(c_color)s%(levelname)-8s%(c_reset)s %(c_fg_cyan)s[%(name)s] ' \
@@ -27,17 +28,44 @@ DEFAULT_LEVEL_COLORS = {
 
 
 class ColorizedFormatter(Formatter):
-    def __init__(self, fmt=None, level_colors=None, hide_lib_diagnose=True, *args, **kwargs):
+    def __init__(
+            self,
+            fmt=None,
+            datefmt=None,
+            style='%',
+            validate=True,
+            *,
+            defaults=None,
+            level_colors=None,
+            hide_lib_diagnose=True
+    ):
         self.level_colors = level_colors or DEFAULT_LEVEL_COLORS
         fmt = fmt or DEFAULT_FORMAT
-        self._formatter = ExceptionFormatter(colorize=True, backtrace=False, diagnose=True, hide_lib_diagnose=hide_lib_diagnose)
+        self._formatter = ExceptionFormatter(colorize=True, backtrace=False, diagnose=True,
+                                             hide_lib_diagnose=hide_lib_diagnose)
 
-        super().__init__(fmt=fmt, *args, **kwargs)
+        kwargs = {
+            'fmt': fmt,
+            'datefmt': datefmt,
+            'style': style,
+            'validate': validate,
+            'defaults': defaults
+        }
+
+        if sys.version_info.major == 3 and sys.version_info.minor < 8:
+            del kwargs['validate']
+        if sys.version_info.major == 3 and sys.version_info.minor < 10:
+            del kwargs['defaults']
+
+        super().__init__(**kwargs)
 
     def format(self, record: LogRecord) -> str:
         color = self.level_colors.get(record.levelno, self.level_colors.get(None, ""))
+        orig = record.__dict__
         record.__dict__ = {**colors, "c_color": color, **record.__dict__}
-        return super().format(record)
+        out = super().format(record)
+        record.__dict__ = orig
+        return out
 
     def formatException(self, ei) -> str:
         ex = self._formatter.format_exception(*ei)
